@@ -4,7 +4,7 @@ import os
 import sys
 import warnings
 from collections import defaultdict
-from typing import List, Optional, Tuple
+from typing import Dict, List, Optional, Tuple
 
 import sqlalchemy as sa
 import sqlparse
@@ -13,11 +13,11 @@ from sqlalchemy.orm import sessionmaker
 
 from .constants import (
     BUILTIN_SCHEMAS,
+    DEFAULT_SCHEMA,
     LOGICAL_SLOT_PREFIX,
     LOGICAL_SLOT_SUFFIX,
     MATERIALIZED_VIEW,
     PLUGIN,
-    SCHEMA,
     TG_OP,
     TRIGGER_FUNC,
     UPDATE,
@@ -29,7 +29,12 @@ from .exc import (
     TableNotFoundError,
 )
 from .node import Node
-from .settings import PG_SSLMODE, PG_SSLROOTCERT, QUERY_CHUNK_SIZE
+from .settings import (
+    PG_SSLMODE,
+    PG_SSLROOTCERT,
+    QUERY_CHUNK_SIZE,
+    QUERY_LITERAL_BINDS,
+)
 from .trigger import CREATE_TRIGGER_TEMPLATE
 from .urls import get_postgres_url
 from .view import create_view, drop_view
@@ -51,7 +56,7 @@ logger = logging.getLogger(__name__)
 class TupleIdentifierType(sa.types.UserDefinedType):
     cache_ok: bool = True
 
-    def get_col_spec(self, **kw) -> str:
+    def get_col_spec(self, **kwargs) -> str:
         return "TID"
 
     def bind_processor(self, dialect):
@@ -69,15 +74,11 @@ class TupleIdentifierType(sa.types.UserDefinedType):
 
 class Base(object):
     def __init__(self, database: str, verbose: bool = False, *args, **kwargs):
-        """Initialize the base class constructor.
-
-        Args:
-            database: The database name
-        """
+        """Initialize the base class constructor."""
         self.__engine = pg_engine(database, **kwargs)
         self.__schemas: Optional[dict] = None
         # models is a dict of f'{schema}.{table}'
-        self.models: dict = {}
+        self.models: Dict[str] = {}
         self.__metadata: dict = {}
         self.__indices: dict = {}
         self.verbose: bool = verbose
@@ -228,14 +229,14 @@ class Base(object):
         return metadata.tables.keys()
 
     def _get_schema(self, schema: str, table: str) -> Tuple[str, str]:
-        pairs = table.split(".")
+        pairs: list = table.split(".")
         if len(pairs) == 2:
             return pairs[0], pairs[1]
         if len(pairs) == 1:
             return schema, pairs[0]
         raise ValueError(f"Invalid definition {table} for schema: {schema}")
 
-    def truncate_table(self, table: str, schema: str = SCHEMA) -> None:
+    def truncate_table(self, table: str, schema: str = DEFAULT_SCHEMA) -> None:
         """Truncate a table.
 
         Note:
@@ -254,7 +255,9 @@ class Base(object):
         query = f'TRUNCATE TABLE "{schema}"."{table}" CASCADE'
         self.execute(query)
 
-    def truncate_tables(self, tables: List[str], schema: str = SCHEMA) -> None:
+    def truncate_tables(
+        self, tables: List[str], schema: str = DEFAULT_SCHEMA
+    ) -> None:
         """Truncate all tables."""
         logger.debug(f"Truncating tables: {tables}")
         for table in tables:
@@ -340,7 +343,7 @@ class Base(object):
         upto_lsn: Optional[int] = None,
         upto_nchanges: Optional[int] = None,
     ):
-        filters: List = []
+        filters: list = []
         statement: str = sa.select(
             [sa.column("xid"), sa.column("data")]
         ).select_from(
@@ -428,7 +431,7 @@ class Base(object):
             pg_namespace = self.model("pg_namespace", "pg_catalog")
 
         alias = pg_class.alias("x")
-        inclause = []
+        inclause: list = []
         for table in tables:
             pairs = table.split(".")
             if len(pairs) == 1:
@@ -976,7 +979,12 @@ def pg_engine(
     return sa.create_engine(url, echo=echo, connect_args=connect_args)
 
 
-def pg_execute(engine, query, values=None, options=None) -> None:
+def pg_execute(
+    engine,
+    query,
+    values: Optional[list] = None,
+    options: Optional[dict] = None,
+) -> None:
     options: dict = options or {"isolation_level": "AUTOCOMMIT"}
     conn = engine.connect()
     try:
@@ -991,7 +999,7 @@ def pg_execute(engine, query, values=None, options=None) -> None:
 
 def create_schema(engine, schema) -> None:
     """Create database schema."""
-    if schema != SCHEMA:
+    if schema != DEFAULT_SCHEMA:
         engine.execute(sa.schema.CreateSchema(schema))
 
 
@@ -1033,6 +1041,11 @@ def compiled_query(
     query: str, label: Optional[str] = None, literal_binds: bool = False
 ) -> None:
     """Compile an SQLAlchemy query with an optional label."""
+
+    # overide env value of literal_binds
+    if QUERY_LITERAL_BINDS:
+        literal_binds = QUERY_LITERAL_BINDS
+
     query: str = str(
         query.compile(
             dialect=sa.dialects.postgresql.dialect(),
@@ -1042,7 +1055,9 @@ def compiled_query(
     query: str = sqlparse.format(query, reindent=True, keyword_case="upper")
     if label:
         logger.debug(f"\033[4m{label}:\033[0m\n{query}")
-        sys.stdout.write(f"\033[4m{label}:\033[0m\n{query}")
+        sys.stdout.write(f"\033[4m{label}:\033[0m\n{query}\n")
     else:
         logging.debug(f"{query}")
-        sys.stdout.write(f"{query}")
+        sys.stdout.write(f"{query}\n")
+    sys.stdout.write("-" * 79)
+    sys.stdout.write("\n")
