@@ -1,6 +1,7 @@
-"""PGSync Settings."""
+"""PGSync settings."""
 import logging
 import logging.config
+import os
 from typing import Optional
 
 from environs import Env
@@ -8,7 +9,7 @@ from environs import Env
 logger = logging.getLogger(__name__)
 
 env = Env()
-env.read_env()
+env.read_env(path=os.path.join(os.getcwd(), ".env"))
 
 # PGSync:
 # path to the application schema config
@@ -27,6 +28,7 @@ CHECKPOINT_PATH = env.str("CHECKPOINT_PATH", default="./")
 LOG_INTERVAL = env.float("LOG_INTERVAL", default=0.5)
 # page block size
 BLOCK_SIZE = env.int("BLOCK_SIZE", default=2048 * 10)
+QUERY_LITERAL_BINDS = env.bool("QUERY_LITERAL_BINDS", default=None)
 
 # Elasticsearch:
 ELASTICSEARCH_SCHEME = env.str("ELASTICSEARCH_SCHEME", default="http")
