@@ -37,14 +37,7 @@ from .exc import (
     SchemaError,
     SuperUserError,
 )
-from .node import (
-    get_node,
-    Node,
-    node_from_table,
-    traverse_breadth_first,
-    traverse_post_order,
-    Tree,
-)
+from .node import get_node, Node, node_from_table, Tree
 from .plugin import Plugins
 from .querybuilder import QueryBuilder
 from .redisqueue import RedisQueue
@@ -57,7 +50,7 @@ from .settings import (
     REPLICATION_SLOT_CLEANUP_INTERVAL,
 )
 from .transform import get_private_keys, transform
-from .utils import get_config, show_settings, threaded, Timer
+from .utils import exit_handler, get_config, show_settings, threaded, Timer
 
 logger = logging.getLogger(__name__)
 
@@ -126,13 +119,13 @@ class Sync(Base):
         except TypeError:
             raise RuntimeError(
                 "Ensure there is at least one replication slot defined "
-                "by setting max_replication_slots=1"
+                "by setting max_replication_slots = 1"
             )
 
         wal_level: Optional[str] = self.pg_settings("wal_level")
         if not wal_level or wal_level.lower() != "logical":
             raise RuntimeError(
-                "Enable logical decoding by setting wal_level=logical"
+                "Enable logical decoding by setting wal_level = logical"
             )
 
         rds_logical_replication: Optional[str] = self.pg_settings(
@@ -174,12 +167,12 @@ class Sync(Base):
 
         root: Node = self.tree.build(self.nodes)
         root.display()
-        for node in traverse_breadth_first(root):
+        for node in root.traverse_breadth_first():
             pass
 
     def analyze(self) -> None:
         root: Node = self.tree.build(self.nodes)
-        for node in traverse_breadth_first(root):
+        for node in root.traverse_breadth_first():
 
             if node.is_root:
                 continue
@@ -195,12 +188,12 @@ class Sync(Base):
                     through_table,
                     node.schema,
                 )
-                foreign_keys = get_foreign_keys(
+                foreign_keys: dict = get_foreign_keys(
                     node.parent,
                     through,
                 )
             else:
-                foreign_keys = get_foreign_keys(
+                foreign_keys: dict = get_foreign_keys(
                     node.parent,
                     node,
                 )
@@ -253,7 +246,7 @@ class Sync(Base):
             user_defined_fkey_tables: dict = {}
 
             root: Node = self.tree.build(self.nodes)
-            for node in traverse_breadth_first(root):
+            for node in root.traverse_breadth_first():
                 if node.schema != schema:
                     continue
                 tables |= set(node.relationship.through_tables)
@@ -282,12 +275,12 @@ class Sync(Base):
         except OSError:
             pass
 
-        self.redis._delete()
+        self.redis.delete()
 
         for schema in self.schemas:
             tables: Set = set([])
             root: Node = self.tree.build(self.nodes)
-            for node in traverse_breadth_first(root):
+            for node in root.traverse_breadth_first():
                 tables |= set(node.relationship.through_tables)
                 tables |= set([node.table])
             self.drop_triggers(schema=schema, tables=tables)
@@ -511,7 +504,7 @@ class Sync(Base):
                     }
                     if self.routing:
                         doc["_routing"] = old_values[self.routing]
-                    if self.es.major_version < 7 and not self.es.opensearch:
+                    if self.es.major_version < 7 and not self.es.is_opensearch:
                         doc["_type"] = "_doc"
                     docs.append(doc)
 
@@ -613,7 +606,7 @@ class Sync(Base):
                 }
                 if self.routing:
                     doc["_routing"] = payload_data[self.routing]
-                if self.es.major_version < 7 and not self.es.opensearch:
+                if self.es.major_version < 7 and not self.es.is_opensearch:
                     doc["_type"] = "_doc"
                 docs.append(doc)
             if docs:
@@ -634,7 +627,7 @@ class Sync(Base):
                 )
                 fields = defaultdict(list)
 
-                _filters = []
+                _filters: list = []
                 for key, value in primary_fields.items():
                     fields[key].append(value)
 
@@ -662,7 +655,7 @@ class Sync(Base):
                     "_index": self.index,
                     "_op_type": "delete",
                 }
-                if self.es.major_version < 7 and not self.es.opensearch:
+                if self.es.major_version < 7 and not self.es.is_opensearch:
                     doc["_type"] = "_doc"
                 docs.append(doc)
             if docs:
@@ -828,7 +821,7 @@ class Sync(Base):
 
         self.query_builder.isouter: bool = True
 
-        for node in traverse_post_order(root):
+        for node in root.traverse_post_order():
 
             self._build_filters(filters, node)
 
@@ -918,6 +911,7 @@ class Sync(Base):
                 bar.update(1)
 
                 row: dict = transform(row, self.nodes)
+
                 row[META] = get_private_keys(keys)
                 if extra:
                     if extra["table"] not in row[META]:
@@ -941,11 +935,13 @@ class Sync(Base):
                 if self.routing:
                     doc["_routing"] = row[self.routing]
 
-                if self.es.major_version < 7 and not self.es.opensearch:
+                if self.es.major_version < 7 and not self.es.is_opensearch:
                     doc["_type"] = "_doc"
 
                 if self._plugins:
                     doc = next(self._plugins.transform([doc]))
+                    if not doc:
+                        continue
 
                 if self.pipeline:
                     doc["pipeline"] = self.pipeline
@@ -969,6 +965,7 @@ class Sync(Base):
         self._checkpoint: int = value
 
     @threaded
+    @exit_handler
     def poll_redis(self) -> None:
         """Consumer which polls Redis continuously."""
         while True:
@@ -980,6 +977,7 @@ class Sync(Base):
             time.sleep(REDIS_POLL_INTERVAL)
 
     @threaded
+    @exit_handler
     def poll_db(self) -> None:
         """
         Producer which polls Postgres continuously.
@@ -1079,6 +1077,7 @@ class Sync(Base):
         self._truncate: bool = True
 
     @threaded
+    @exit_handler
     def truncate_slots(self) -> None:
         """Truncate the logical replication slot."""
         while True:
@@ -1088,6 +1087,7 @@ class Sync(Base):
             time.sleep(REPLICATION_SLOT_CLEANUP_INTERVAL)
 
     @threaded
+    @exit_handler
     def status(self):
         while True:
             sys.stdout.write(
@@ -1222,13 +1222,13 @@ def main(
 
     if analyze:
         for document in json.load(open(config)):
-            sync = Sync(document, verbose=verbose, **kwargs)
+            sync: Sync = Sync(document, verbose=verbose, **kwargs)
             sync.analyze()
         return
 
     with Timer():
         for document in json.load(open(config)):
-            sync = Sync(document, verbose=verbose, **kwargs)
+            sync: Sync = Sync(document, verbose=verbose, **kwargs)
             sync.pull()
             if daemon:
                 sync.receive()
