@@ -2,8 +2,8 @@
 import logging
 import os
 import sys
+import threading
 from datetime import timedelta
-from threading import Thread
 from time import time
 from typing import Optional
 
@@ -16,6 +16,7 @@ from .settings import (
     PG_HOST,
     PG_PORT,
     PG_USER,
+    REDIS_AUTH,
     REDIS_DB,
     REDIS_HOST,
     REDIS_PORT,
@@ -44,20 +45,50 @@ class Timer:
         self.message: str = message or ""
 
     def __enter__(self):
-        self.start = time()
+        self.start: float = time()
         return self
 
     def __exit__(self, *args):
-        end: float = time()
-        elapsed: float = end - self.start
+        elapsed: float = time() - self.start
         sys.stdout.write(
             f"{self.message} {(timedelta(seconds=elapsed))} "
             f"({elapsed:2.2f} sec)\n"
         )
 
 
-def show_settings(schema: str = None, **kwargs) -> None:
-    """Show configuration."""
+def threaded(func):
+    """Decorator for threaded code execution."""
+
+    def wrapper(*args, **kwargs) -> threading.Thread:
+        thread: threading.Thread = threading.Thread(
+            target=func, args=args, kwargs=kwargs
+        )
+        thread.start()
+        return thread
+
+    return wrapper
+
+
+def exit_handler(func):
+    """Decorator for threaded exception handling."""
+
+    def wrapper(*args, **kwargs):
+        try:
+            fn = func(*args, **kwargs)
+        except Exception as e:
+            name: str = threading.currentThread().getName()
+            sys.stdout.write(
+                f"Exception in {func.__name__}() for thread {name}: {e}\n"
+                f"Exiting...\n"
+            )
+            os._exit(-1)
+        return fn
+
+    return wrapper
+
+
+def show_settings(schema: Optional[str] = None, **kwargs) -> None:
+    """Show settings."""
     logger.info("\033[4mSettings\033[0m:")
     logger.info(f'{"Schema":<10s}: {schema or SCHEMA}')
     logger.info("-" * 65)
@@ -83,21 +114,17 @@ def show_settings(schema: str = None, **kwargs) -> None:
             f"{ELASTICSEARCH_HOST}:{ELASTICSEARCH_PORT}"
         )
     logger.info("\033[4mRedis\033[0m:")
-    logger.info(f"URL: {REDIS_SCHEME}://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}")
+    if REDIS_AUTH:
+        logger.info(
+            f"URL: {REDIS_SCHEME}://:****@{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}"
+        )
+    else:
+        logger.info(
+            f"URL: {REDIS_SCHEME}://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}"
+        )
     logger.info("-" * 65)
 
 
-def threaded(fn):
-    """Decorator for threaded code execution."""
-
-    def wrapper(*args, **kwargs) -> Thread:
-        thread: Thread = Thread(target=fn, args=args, kwargs=kwargs)
-        thread.start()
-        return thread
-
-    return wrapper
-
-
 def get_config(config: Optional[str] = None) -> str:
     """
     Return the schema config for PGSync.
