@@ -9,7 +9,7 @@ from sqlalchemy.orm import sessionmaker
 from sqlalchemy.schema import UniqueConstraint
 
 from pgsync.base import Base, create_database, drop_database
-from pgsync.constants import SCHEMA
+from pgsync.constants import DEFAULT_SCHEMA
 from pgsync.sync import Sync
 from pgsync.urls import get_postgres_url
 
@@ -335,7 +335,7 @@ def table_creator(base, connection, model_mapping):
     pg_base = Base(connection.engine.url.database)
     pg_base.create_triggers(
         connection.engine.url.database,
-        SCHEMA,
+        DEFAULT_SCHEMA,
     )
     pg_base.drop_replication_slot(f"{connection.engine.url.database}_testdb")
     pg_base.create_replication_slot(f"{connection.engine.url.database}_testdb")
