@@ -86,7 +86,7 @@ class TestRoot(object):
         except Exception:
             raise
 
-        sync.redis._delete()
+        sync.redis.delete()
         session.connection().engine.connect().close()
         session.connection().engine.dispose()
         sync.es.close()
