@@ -91,7 +91,7 @@ class TestParentSingleChildFkOnChild(object):
         except Exception:
             raise
 
-        sync.redis._delete()
+        sync.redis.delete()
         session.connection().engine.connect().close()
         session.connection().engine.dispose()
         sync.es.close()
